Module ordered
pollable_
map
0.2.0
Module ordered
Module Items
Structs
In pollable_
map::
futures
pollable_map
::
futures
Module
ordered
Structs

Ordered
Future
Set
An unbounded queue of futures imposed a FIFO order while polling one future at a time and returning the output to stream before popping the next future in queue to be polled.