pub struct Optional<T> { /* private fields */ }Expand description
A reusable future or stream based on Option.
By default, Optional will be empty, similar to Option::None, which would return Poll::Pending when polled,
but if a Future or Stream is supplied either upon construction via Optional::new or
is set via Optional::replace, it would then be polled once Optional
is polled. Once the future is polled to completion, the results will be returned, with
Optional being empty.
Implementations
Sourceimpl<T> Optional<T>
impl<T> Optional<T>
Sourcepub fn with_future(future: T) -> Selfwhere
T: Future,
pub fn with_future(future: T) -> Selfwhere
T: Future,
Sourcepub fn with_stream(stream: T) -> Selfwhere
T: Stream,
pub fn with_stream(stream: T) -> Selfwhere
T: Stream,
Sourcepub fn take(&mut self) -> Option<T>
pub fn take(&mut self) -> Option<T>
Takes the future or stream out, leaving the Optional empty.
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
Returns false if the future or stream doesn’t exist or has been completed.
Sourcepub fn replace(&mut self, task: T) -> Option<T>
pub fn replace(&mut self, task: T) -> Option<T>
Replaces the current the future or stream with a new one, returning the previous value if present.
Sourcepub fn set(self: Pin<&mut Self>, task: T)
pub fn set(self: Pin<&mut Self>, task: T)
Replaces the current future or stream in place without moving the previous value.
Sourcepub fn as_pin_mut(&mut self) -> Option<Pin<&mut T>>where
T: Unpin,
pub fn as_pin_mut(&mut self) -> Option<Pin<&mut T>>where
T: Unpin,
Returns a constructed Option<Pin<&mut T>>.
Sourcepub fn pinned_as_mut(self: Pin<&mut Self>) -> Option<Pin<&mut T>>
pub fn pinned_as_mut(self: Pin<&mut Self>) -> Option<Pin<&mut T>>
Return a constructed Option<Pin<&mut T>>.